<?php

namespace app\admin\controller\life;

use app\controller\Curd;
use app\model\FarmGoods;
use app\admin\validate\life\FarmGoodsValidate;
use support\Request;
use support\Response;

class FarmGoodsController extends Curd
{
    public function __construct()
    {
        $this->model = new FarmGoods();
        $this->validate = true;
        $this->validateClass = new FarmGoodsValidate();
    }

    /**
     * @Desc 列表
     * @Author Gorden
     * @Date 2024/2/28 10:21
     *
     * @param Request $request
     * @return Response
     * @throws \support\exception\BusinessException
     */
    public function select(Request $request): Response
    {
        [$where, $format, $limit, $field, $order] = $this->selectInput($request);
        $where['goods_is_del'] = 0;
        $query = $this->doSelect($where, $field, $order);
        return $this->doFormat($query, $format, $limit);
    }

    /**
     * @Desc 删除
     * @Author Gorden
     * @Date 2024/2/28 10:21
     *
     * @param Request $request
     * @return Response
     * @throws \support\exception\BusinessException
     */
    public function delete(Request $request): Response
    {
        $ids = $this->deleteInput($request);
        $this->doSoftDelete($ids, ['goods_is_del' => 1]);

        return json_success('success');
    }

    /**
     * @Desc 修改商品状态
     * @Author Gorden
     * @Date 2024/2/28 10:35
     *
     * @param Request $request
     * @return Response
     */
    public function updateStatus(Request $request)
    {
        return $this->updateField($request->post('goods_id'), 'goods_status', $request->post('goods_status'));
    }

    /**
     * @Desc 执行插入数据
     * @Author Gorden
     * @Date 2024/2/28 10:10
     *
     * @param array $data
     * @return mixed|null
     */
    protected function doInsert(array $data)
    {
        $primary_key = $this->model->getKeyName();
        $model_class = get_class($this->model);
        $model = new $model_class;
        $data['goods_content'] = htmlspecialchars($data['goods_content']);
        foreach ($data as $key => $val) {
            $model->{$key} = $val;
        }
        $model->save();
        return $primary_key ? $model->$primary_key : null;
    }
}